==> jcommons-lang-4.7.0-sources.jar: de/alpharogroup/string/MalformedUnicodeException.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.string;

/**
 * The Class MalformedUnicodeException.
 */
public class MalformedUnicodeException extends RuntimeException
{

	/**
	 * The serialVersionUID.
	 */
	private static final long serialVersionUID = -1280189273365922248L;

	/**
	 * Instantiates a new malformed unicode exception.
	 */
	public MalformedUnicodeException()
	{
		super();
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param message
	 *            the message
	 */
	public MalformedUnicodeException(final String message)
	{
		super(message);
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param message
	 *            the message
	 * @param cause
	 *            the cause
	 */
	public MalformedUnicodeException(final String message, final Throwable cause)
	{
		super(message, cause);
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param cause
	 *            the cause
	 */
	public MalformedUnicodeException(final Throwable cause)
	{
		super(cause);
	}

}

==> jcommons-lang-4.28.1-sources.jar: de/alpharogroup/string/MalformedUnicodeException.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.string;

/**
 * The class MalformedUnicodeException.
 */
public class MalformedUnicodeException extends RuntimeException
{

	/**
	 * The serialVersionUID.
	 */
	private static final long serialVersionUID = -1280189273365922248L;

	/**
	 * Instantiates a new malformed unicode exception.
	 */
	public MalformedUnicodeException()
	{
		super();
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param message
	 *            the message
	 */
	public MalformedUnicodeException(final String message)
	{
		super(message);
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param message
	 *            the message
	 * @param cause
	 *            the cause
	 */
	public MalformedUnicodeException(final String message, final Throwable cause)
	{
		super(message, cause);
	}

	/**
	 * Instantiates a new malformed unicode exception.
	 *
	 * @param cause
	 *            the cause
	 */
	public MalformedUnicodeException(final Throwable cause)
	{
		super(cause);
	}

}
